# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, TYPE_CHECKING

from azure.core.rest import HttpRequest, HttpResponse
from azure.mgmt.core import ARMPipelineClient

from . import models
from ._configuration import MicrosoftLogzConfiguration
from ._serialization import Deserializer, Serializer
from .operations import (
    MonitorOperations,
    MonitorsOperations,
    Operations,
    SingleSignOnOperations,
    SubAccountOperations,
    SubAccountTagRulesOperations,
    TagRulesOperations,
)

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from azure.core.credentials import TokenCredential


class MicrosoftLogz:  # pylint: disable=client-accepts-api-version-keyword,too-many-instance-attributes
    """MicrosoftLogz.

    :ivar monitors: MonitorsOperations operations
    :vartype monitors: azure.mgmt.logz.operations.MonitorsOperations
    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.logz.operations.Operations
    :ivar tag_rules: TagRulesOperations operations
    :vartype tag_rules: azure.mgmt.logz.operations.TagRulesOperations
    :ivar single_sign_on: SingleSignOnOperations operations
    :vartype single_sign_on: azure.mgmt.logz.operations.SingleSignOnOperations
    :ivar sub_account: SubAccountOperations operations
    :vartype sub_account: azure.mgmt.logz.operations.SubAccountOperations
    :ivar sub_account_tag_rules: SubAccountTagRulesOperations operations
    :vartype sub_account_tag_rules: azure.mgmt.logz.operations.SubAccountTagRulesOperations
    :ivar monitor: MonitorOperations operations
    :vartype monitor: azure.mgmt.logz.operations.MonitorOperations
    :param credential: Credential needed for the client to connect to Azure. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. Required.
    :type subscription_id: str
    :param base_url: Service URL. Default value is "https://management.azure.com".
    :type base_url: str
    :keyword api_version: Api Version. Default value is "2020-10-01". Note that overriding this
     default value may result in unsupported behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: str = "https://management.azure.com",
        **kwargs: Any
    ) -> None:
        self._config = MicrosoftLogzConfiguration(credential=credential, subscription_id=subscription_id, **kwargs)
        self._client = ARMPipelineClient(base_url=base_url, config=self._config, **kwargs)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)
        self._serialize.client_side_validation = False
        self.monitors = MonitorsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.tag_rules = TagRulesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.single_sign_on = SingleSignOnOperations(self._client, self._config, self._serialize, self._deserialize)
        self.sub_account = SubAccountOperations(self._client, self._config, self._serialize, self._deserialize)
        self.sub_account_tag_rules = SubAccountTagRulesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.monitor = MonitorOperations(self._client, self._config, self._serialize, self._deserialize)

    def _send_request(self, request: HttpRequest, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client._send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        request_copy.url = self._client.format_url(request_copy.url)
        return self._client.send_request(request_copy, **kwargs)

    def close(self):
        # type: () -> None
        self._client.close()

    def __enter__(self):
        # type: () -> MicrosoftLogz
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details):
        # type: (Any) -> None
        self._client.__exit__(*exc_details)
